#[non_exhaustive]pub enum EncryptionMethod {
ZipCrypto,
Aes {
key_size: u16,
check_crc32: bool,
},
}Expand description
The method used to encrypt a file.
eazip does not provide the tools to decrypt these files, but provides the
required metadata if you really need to.
This is only provided for completeness, please don’t use this in scenarios
where security actually matters and use proper tools (eg age).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ZipCrypto
Legacy ZipCrypto encryption.
Aes
The file is encrypted using AES in CTR mode.
See the specification for the format of the encrypted files.