Archive

Struct Archive 

pub struct Archive<R> { /* private fields */ }
An open ZIP archive.

This type owns the reader. If you need something more flexible, use RawArchive instead.

Example

Print the name and content of each file in the archive:

let mut archive = eazip::Archive::open("example.zip")?;

for i in 0..archive.entries().len() {
    let mut entry = archive.get_by_index(i).unwrap();
    let name = entry.metadata().name();
    let content = std::io::read_to_string(entry.read()?)?;

    println!("{name}: {content}");
}

Implementations

Source

impl Archive<BufReader<File>>

pub fn open(path: impl AsRef<Path>) -> Result<Self>

Opens the given file as a ZIP archive.

Source

impl<R: BufRead + Seek> Archive<R>

pub fn new(reader: R) -> Result<Self>

Opens a ZIP archive from a reader.

This also perform many validation checks on the archive to make sure that is it well-formed and does not have dangerous or duplicated paths. The validity of file contents is checked lazily when reading them.

The exact rules around validation are not part of semver guaranties and may change at every release.

The targets of symlinks are not checked yet here, though they are through extract and extract_parallel.

pub fn entries(&self) -> &[Metadata]

Gets the list of entries in the archive.

pub fn get_by_index(&mut self, index: usize) -> Option<File<'_, R>>

Gets a file by its index.

pub fn get_by_name(&mut self, name: &str) -> Option<File<'_, R>>

Gets a file by its name.

pub fn index_of(&self, name: &str) -> Option<usize>

Gets the index of a file in Self::entries by its name.

pub fn commment(&self) -> &[u8]

Gets the comment of the archive.

pub fn extract(&mut self, at: impl AsRef<Path>) -> Result<()>

Extracts the archive to the given directory.

The directory will be created if needed, but not its parent.

pub fn get_ref(&self) -> &R

Gets a shared reference to the underlying reader.

pub fn get_mut(&mut self) -> &mut R

Gets a mutable reference to the underlying reader.