Metadata

Struct Metadata 

pub struct Metadata {
    pub data_offset: u64,
    pub compressed_size: u64,
    pub uncompressed_size: u64,
    pub compression_method: CompressionMethod,
    pub crc32: u32,
    pub file_type: FileType,
    pub modification_time: Option<Timestamp>,
    pub access_time: Option<Timestamp>,
    pub creation_time: Option<Timestamp>,
    pub encryption: Option<EncryptionMethod>,
    /* private fields */
}
The metadata of a ZIP entry.

Fields

data_offset: u64compressed_size: u64uncompressed_size: u64compression_method: CompressionMethodcrc32: u32file_type: FileTypemodification_time: Option<Timestamp>access_time: Option<Timestamp>creation_time: Option<Timestamp>encryption: Option<EncryptionMethod>

Implementations

Source

impl Metadata

pub fn is_encrypted(&self) -> bool

Returns true if this file is encrypted.

pub fn name(&self) -> &str

Gets the name of this entry.

pub fn comment(&self) -> &str

Gets the comment of this entry.

pub fn read<R: BufRead + Seek>(&self, reader: R) -> Result<impl Read + use<R>>

Returns a reader with the content of the file.

Unsupported compression methods and encrypted files will return an error.

pub fn read_stored<R: Read + Seek>(&self, reader: R) -> Result<Take<R>>

Returns a reader with the content of the file.

Errors if the file is compressed, encrypted or corrupted. Is is not necessary to use Metadata::content_checker on the result.

It is useful if you know that the file is stored as-is and you want to take advantage of the BufReader or the Seek implementation.

pub fn read_raw<R: Read + Seek>(&self, reader: R) -> Result<Take<R>>

Returns a reader with the raw, uncompressed, content of the file.

The uncompressed content should be checked with content_checker.

pub fn content_checker<R: Read>(&self, reader: R) -> impl Read + use<R>

Wraps a reader to check that its content matches this metadata.

It is particularly useful in combinaison of read_raw.

pub fn extract<R: BufRead + Seek>( &self, reader: &mut R, root: impl AsRef<Path>, ) -> Result<()>

Extracts this entry as if the root of the archive was at root.