pub struct Compressor<W: Write>(/* private fields */);Expand description
An adapter to compress a stream.
Implementations
Sourceimpl<W: Write> Compressor<W>
impl<W: Write> Compressor<W>
Sourcepub fn new(
writer: W,
method: CompressionMethod,
level: Option<i32>,
) -> Result<Self>
pub fn new( writer: W, method: CompressionMethod, level: Option<i32>, ) -> Result<Self>
Creates a new Compressor.
The level parameter signification depends on the method used. None
always means “default level” and is always supported.
Compression methods unsupported by this crate will cause an error.
Sourcepub fn compression_method(&self) -> CompressionMethod
pub fn compression_method(&self) -> CompressionMethod
Returns the compression method used by this compressor
Sourcepub fn get_mut(&mut self) -> &mut W
pub fn get_mut(&mut self) -> &mut W
Gets a mutable reference to the underlying writer.
It is inadvisable to directly write to the underlying writer.